/**
 * @fileoverview Enforce onmouseover/onmouseout are
 *  accompanied by onfocus/onblur.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mouseOverErrorMessage = 'onMouseOver must be accompanied by onFocus for accessibility.';
var mouseOutErrorMessage = 'onMouseOut must be accompanied by onBlur for accessibility.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;

      // Check onmouseover / onfocus pairing.
      var hasOnMouseOver = (0, _hasAttribute2.default)(attributes, 'onMouseOver');
      if (Boolean(hasOnMouseOver) === true) {
        var hasOnFocus = (0, _hasAttribute2.default)(attributes, 'onFocus');
        if (hasOnFocus === false) {
          context.report({
            node: node,
            message: mouseOverErrorMessage
          });
        }
      }

      // Checkout onmouseout / onblur pairing
      var hasOnMouseOut = (0, _hasAttribute2.default)(attributes, 'onMouseOut');
      if (Boolean(hasOnMouseOut) === true) {
        var hasOnBlur = (0, _hasAttribute2.default)(attributes, 'onBlur');
        if (hasOnBlur === false) {
          context.report({
            node: node,
            message: mouseOutErrorMessage
          });
        }
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];