/**
 * @fileoverview Enforce label tags have htmlFor attribute.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _hasAttribute = require('../util/hasAttribute');

var _hasAttribute2 = _interopRequireDefault(_hasAttribute);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var errorMessage = 'Form controls using a label to identify them must be ' + 'programmatically associated with the control using htmlFor';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var type = node.name.name;
      if (type !== 'label') {
        return;
      }

      var hasHtmlForAttr = (0, _hasAttribute2.default)(node.attributes, 'htmlFor');

      if (hasHtmlForAttr === false) {
        context.report({
          node: node,
          message: errorMessage
        });
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];